.. conf.py documentation master file, created by
   sphinx-quickstart on Sat Dec 27 23:54:16 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

conf.py documentation
=====================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.

Welcome to qubee-nlp's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   index.md


